extract_query() adds the query string of a URL as a new column.
The query is defined as the part following a "?" after the path
but not including a fragment (anything after a "#").
Arguments
- wt
webtrack data object
- varname
character. name of the column from which to extract the host. Defaults to
"url".- decode
logical. Whether to decode the query (see
utils::URLdecode()), default to TRUE